@@ -257,6 +257,8 @@ class OssFilesPipeline(MediaPipeline):
                 except Exception as e:
                     print(e)
                     return None
+            else :
+                return response
 
         # response.body = content
         if magic.from_buffer(response.body, mime=True).split('/')[-1] == 'pdf':
